==> owncloud-5.0.0.tar.bz2: owncloud/apps/bookmarks/l10n/es_AR.php <==
<?php $TRANSLATIONS = array(
"No file provided for import" => "No se proveyeron archivos para importar",
"Unsupported file type for import" => "Tipo de archivo no soportado para importar",
"Bookmarks" => "Marcadores",
"Tags" => "Etiquetas",
"Filter by tag" => "Filtrar por etiquetas",
"Edit bookmark" => "Editar marcadores",
"Are you sure you want to remove this tag from every entry?" => "¿Estás seguro de que querés borrar esta etiqueta de todos los elementos?",
"Warning" => "Atención",
"Import error" => "Error al importar",
"Import completed successfully." => "Importación completada con éxito.",
"Uploading..." => "Subiendo...",
"Bookm." => "Marc.",
"Add a bookmark" => "Agregar un marcador",
"Close" => "Cerrar",
"The title of the page" => "El título de la página",
"The address of the page" => "La dirección de la página",
"Description of the page" => "Descripción de la página",
"Save" => "Guardar",
"Delete" => "Borrar",
"Edit" => "Editar",
"Cancel" => "Cancelar",
"Drag this to your browser bookmarks and click it, when you want to bookmark a webpage quickly:" => "Arrastrá desde aquí a los marcadores de tu navegador, y hacé click cuando quieras marcar una página web:",
"Read later" => "Leer después",
"Address" => "Dirección",
"Add" => "Agregar",
"Related Tags" => "Etiquetas relacionadas",
"Settings" => "Configuración",
"You have no bookmarks" => "No tenés marcadores",
"You can also try to import a bookmark file" => "También podés intentar importar un archivo de marcadores",
"Bookmarklet" => "Marcadores",
"Export & Import" => "Exportar e importar",
"Export" => "Exportar",
"Import" => "Importar"
);

==> owncloud_7.0.4+dfsg.orig.tar.bz2: owncloud/apps/bookmarks/l10n/es_AR.php <==
<?php
$TRANSLATIONS = array(
"No file provided for import" => "No se proveyeron archivos para importar",
"Unsupported file type for import" => "Tipo de archivo no soportado para importar",
"Bookmarks" => "Marcadores",
"Tags" => "Etiquetas",
"Filter by tag" => "Filtrar por etiquetas",
"Edit bookmark" => "Editar marcadores",
"Are you sure you want to remove this tag from every entry?" => "¿Estás seguro de que querés borrar esta etiqueta de todos los elementos?",
"Warning" => "Atención",
"Import error" => "Error al importar",
"Import completed successfully." => "Importación completada con éxito.",
"Uploading..." => "Subiendo...",
"Bookm." => "Marc.",
"Add a bookmark" => "Agregar un marcador",
"Close" => "Cerrar",
"The title of the page" => "El título de la página",
"The address of the page" => "La dirección de la página",
"Description of the page" => "Descripción de la página",
"Save" => "Guardar",
"Delete" => "Borrar",
"Edit" => "Editar",
"Cancel" => "Cancelar",
"Drag this to your browser bookmarks and click it, when you want to bookmark a webpage quickly:" => "Arrastrá desde aquí a los marcadores de tu navegador, y hacé click cuando quieras marcar una página web:",
"Add to ownCloud" => "Agregar a ownCloud",
"Address" => "Dirección",
"Add" => "Agregar",
"Related Tags" => "Etiquetas relacionadas",
"Settings" => "Configuración",
"You have no bookmarks" => "No tenés marcadores",
"You can also try to import a bookmark file" => "También podés intentar importar un archivo de marcadores",
"Bookmarklet" => "Marcadores",
"Export & Import" => "Exportar e importar",
"Export" => "Exportar",
"Import" => "Importar"
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";
